==> projen-0.45.3-sources.jar: io/github/cdklabs/projen/github/PullRequestTemplate.java <==
package io.github.cdklabs.projen.github;

/**
 * (experimental) Template for GitHub pull requests.
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.47.0 (build 86d2c33)", date = "2021-12-20T00:39:28.769Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
@software.amazon.jsii.Jsii(module = io.github.cdklabs.projen.$Module.class, fqn = "projen.github.PullRequestTemplate")
public class PullRequestTemplate extends io.github.cdklabs.projen.TextFile {

    protected PullRequestTemplate(final software.amazon.jsii.JsiiObjectRef objRef) {
        super(objRef);
    }

    protected PullRequestTemplate(final software.amazon.jsii.JsiiObject.InitializationMode initializationMode) {
        super(initializationMode);
    }

    /**
     * @param github This parameter is required.
     * @param options
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public PullRequestTemplate(final @org.jetbrains.annotations.NotNull io.github.cdklabs.projen.github.GitHub github, final @org.jetbrains.annotations.Nullable io.github.cdklabs.projen.github.PullRequestTemplateOptions options) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, new Object[] { java.util.Objects.requireNonNull(github, "github is required"), options });
    }

    /**
     * @param github This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public PullRequestTemplate(final @org.jetbrains.annotations.NotNull io.github.cdklabs.projen.github.GitHub github) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, new Object[] { java.util.Objects.requireNonNull(github, "github is required") });
    }

    /**
     * (experimental) A fluent builder for {@link io.github.cdklabs.projen.github.PullRequestTemplate}.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public static final class Builder implements software.amazon.jsii.Builder<io.github.cdklabs.projen.github.PullRequestTemplate> {
        /**
         * @return a new instance of {@link Builder}.
         * @param github This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public static Builder create(final io.github.cdklabs.projen.github.GitHub github) {
            return new Builder(github);
        }

        private final io.github.cdklabs.projen.github.GitHub github;
        private io.github.cdklabs.projen.github.PullRequestTemplateOptions.Builder options;

        private Builder(final io.github.cdklabs.projen.github.GitHub github) {
            this.github = github;
        }

        /**
         * (experimental) The contents of the template.
         * <p>
         * You can use <code>addLine()</code> to add additional lines.
         * <p>
         * Default: - a standard default template will be created.
         * <p>
         * @return {@code this}
         * @param lines The contents of the template. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder lines(final java.util.List<java.lang.String> lines) {
            this.options().lines(lines);
            return this;
        }

        /**
         * @returns a newly built instance of {@link io.github.cdklabs.projen.github.PullRequestTemplate}.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        @Override
        public io.github.cdklabs.projen.github.PullRequestTemplate build() {
            return new io.github.cdklabs.projen.github.PullRequestTemplate(
                this.github,
                this.options != null ? this.options.build() : null
            );
        }

        private io.github.cdklabs.projen.github.PullRequestTemplateOptions.Builder options() {
            if (this.options == null) {
                this.options = new io.github.cdklabs.projen.github.PullRequestTemplateOptions.Builder();
            }
            return this.options;
        }
    }
}

==> projen-0.79.0-sources.jar: io/github/cdklabs/projen/github/PullRequestTemplate.java <==
package io.github.cdklabs.projen.github;

/**
 * (experimental) Template for GitHub pull requests.
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.94.0 (build b380f01)", date = "2024-01-10T23:18:45.436Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
@software.amazon.jsii.Jsii(module = io.github.cdklabs.projen.$Module.class, fqn = "projen.github.PullRequestTemplate")
public class PullRequestTemplate extends io.github.cdklabs.projen.TextFile {

    protected PullRequestTemplate(final software.amazon.jsii.JsiiObjectRef objRef) {
        super(objRef);
    }

    protected PullRequestTemplate(final software.amazon.jsii.JsiiObject.InitializationMode initializationMode) {
        super(initializationMode);
    }

    /**
     * @param github This parameter is required.
     * @param options
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public PullRequestTemplate(final @org.jetbrains.annotations.NotNull io.github.cdklabs.projen.github.GitHub github, final @org.jetbrains.annotations.Nullable io.github.cdklabs.projen.github.PullRequestTemplateOptions options) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, new Object[] { java.util.Objects.requireNonNull(github, "github is required"), options });
    }

    /**
     * @param github This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public PullRequestTemplate(final @org.jetbrains.annotations.NotNull io.github.cdklabs.projen.github.GitHub github) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, new Object[] { java.util.Objects.requireNonNull(github, "github is required") });
    }

    /**
     * (experimental) Returns the <code>PullRequestTemplate</code> instance associated with a project or <code>undefined</code> if there is no PullRequestTemplate.
     * <p>
     * @return A PullRequestTemplate
     * @param project The project. This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public static @org.jetbrains.annotations.Nullable io.github.cdklabs.projen.github.PullRequestTemplate of(final @org.jetbrains.annotations.NotNull io.github.cdklabs.projen.Project project) {
        return software.amazon.jsii.JsiiObject.jsiiStaticCall(io.github.cdklabs.projen.github.PullRequestTemplate.class, "of", software.amazon.jsii.NativeType.forClass(io.github.cdklabs.projen.github.PullRequestTemplate.class), new Object[] { java.util.Objects.requireNonNull(project, "project is required") });
    }

    /**
     * (experimental) A fluent builder for {@link io.github.cdklabs.projen.github.PullRequestTemplate}.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public static final class Builder implements software.amazon.jsii.Builder<io.github.cdklabs.projen.github.PullRequestTemplate> {
        /**
         * @return a new instance of {@link Builder}.
         * @param github This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public static Builder create(final io.github.cdklabs.projen.github.GitHub github) {
            return new Builder(github);
        }

        private final io.github.cdklabs.projen.github.GitHub github;
        private io.github.cdklabs.projen.github.PullRequestTemplateOptions.Builder options;

        private Builder(final io.github.cdklabs.projen.github.GitHub github) {
            this.github = github;
        }

        /**
         * (experimental) The contents of the template.
         * <p>
         * You can use <code>addLine()</code> to add additional lines.
         * <p>
         * Default: - a standard default template will be created.
         * <p>
         * @return {@code this}
         * @param lines The contents of the template. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder lines(final java.util.List<java.lang.String> lines) {
            this.options().lines(lines);
            return this;
        }

        /**
         * @return a newly built instance of {@link io.github.cdklabs.projen.github.PullRequestTemplate}.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        @Override
        public io.github.cdklabs.projen.github.PullRequestTemplate build() {
            return new io.github.cdklabs.projen.github.PullRequestTemplate(
                this.github,
                this.options != null ? this.options.build() : null
            );
        }

        private io.github.cdklabs.projen.github.PullRequestTemplateOptions.Builder options() {
            if (this.options == null) {
                this.options = new io.github.cdklabs.projen.github.PullRequestTemplateOptions.Builder();
            }
            return this.options;
        }
    }
}
